@@ -10,7 +10,7 @@ def echo():
 
 
 async def main():
-    bot = MatrixBot(display_name="Echo Bot")
+    bot = MatrixBot()
     bot.set_auto_join()
     bot.register_command(echo(), accepted_aliases="", make_default=True)
     await bot.start_bot()
